// Lrp Network Monitor: Simple network monitor written in Java
// Copyright (C) 2000 Martin Hejl
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


/**
 * Class that stores the information received from the host about a specific network device
 *
 * @author       Martin Hejl
 * @version      20001105 0.2beta
 */
public class InterfaceInfo {

	public static final int DIRECTION_RECEIVE = 0;
	public static final int DIRECTION_TRANSMIT = 1;

	protected String ifName;
	protected String ifStatus;
	protected long rBytes;
	protected long rPackets;
	protected long rErrors;
	protected long rDrop;
	protected long rFifo;
	protected long rFrame;
	protected long rCompressed;
	protected long rMulticast;
	protected long tBytes;
	protected long tPackets;
	protected long tErrors;
	protected long tColls;
	protected long tCarrier;
	protected long tDrop;
	protected long tFifo;
	protected long tCompressed;

	InterfaceInfo() {
		ifName="";
		ifStatus="";
		rBytes=-1;
		rPackets=-1;
		rErrors=-1;
		rDrop=-1;
		rFifo=-1;
		rFrame=-1;
		rCompressed=-1;
		rMulticast=-1;
		tBytes=-1;
		tPackets=-1;
		tErrors=-1;
		tDrop=-1;
		tFifo=-1;
		tCompressed=-1;
		tColls=-1;
		tCarrier=-1;
	}

	InterfaceInfo(	String if_Name, String if_Status, long r_Bytes, long r_Packets,
					long r_Errors, long r_Drop, long r_Fifo, long r_Frame, long r_Compressed,
					long r_Multicast, long t_Bytes, long t_Packets, long t_Errors,
					long t_Drop, long t_Fifo, long t_Compressed, long t_Colls, long t_Carrier) {
		ifName=if_Name;
		ifStatus=if_Status;

		rBytes=r_Bytes;
		rPackets=r_Packets;
		rErrors=r_Errors;
		rDrop=r_Drop;
		rFifo=r_Fifo;
		rFrame=r_Frame;
		rCompressed=r_Compressed;
		rMulticast=r_Multicast;
		tBytes=t_Bytes;
		tPackets=t_Packets;
		tErrors=t_Errors;
		tDrop=t_Drop;
		tFifo=t_Fifo;
		tCompressed=t_Compressed;
		tColls=t_Colls;
		tCarrier=t_Carrier;
	}


	public long getBytes(int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				return (rBytes);
			case DIRECTION_TRANSMIT:
				return (tBytes);
		}
		return -1;
	}

	public long getPackets(int direction) {
		switch (direction) {
			case DIRECTION_RECEIVE:
				return (rPackets);
			case DIRECTION_TRANSMIT:
				return (tPackets);
		}
		return -1;
	}

	public long getErrors(int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				return (rErrors);
			case DIRECTION_TRANSMIT:
				return (tErrors);
		}
		return -1;
	}

	public long getDrop(int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				return (rDrop);
			case DIRECTION_TRANSMIT:
				return (tDrop);
		}
		return -1;
	}

	public long getFifo(int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				return (rFifo);
			case DIRECTION_TRANSMIT:
				return (tFifo);
		}
		return -1;
	}

	public long getFrame(int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				return (rFrame);
			case DIRECTION_TRANSMIT:
				return (-1);
		}
		return -1;
	}

	public long getCompressed(int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				return (rCompressed);
			case DIRECTION_TRANSMIT:
				return (tCompressed);
		}
		return -1;
	}
	public long getColls(int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				return (-1);
			case DIRECTION_TRANSMIT:
				return (tColls);
		}
		return -1;
	}

	public long getCarrier(int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				return (-1);
			case DIRECTION_TRANSMIT:
				return (tCarrier);
		}
		return -1;
	}

	public long getMulticast(int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				return (rMulticast);
			case DIRECTION_TRANSMIT:
				return (-1);
		}
		return -1;
	}

	public String getName(){
		return(ifName);
	}


	public String getStatus(){
		return(ifStatus);
	}


	public void setBytes(long l, int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				rBytes=l;
				break;
			case DIRECTION_TRANSMIT:
				tBytes=l;
				break;
		}

	}

	public void setPackets(long l, int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				rPackets=l;
				break;
			case DIRECTION_TRANSMIT:
				tPackets=l;
				break;
		}

	}

	public void setErrors(long l, int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				rErrors=l;
				break;
			case DIRECTION_TRANSMIT:
				tErrors=l;
				break;
		}

	}

	public void setDrop(long l, int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				rDrop=l;
				break;
			case DIRECTION_TRANSMIT:
				tDrop=l;
				break;
		}

	}

	public void setFifo(long l, int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				rFifo=l;
				break;
			case DIRECTION_TRANSMIT:
				tFifo=l;
				break;
		}

	}

	public void setFrame(long l, int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				rFrame=l;
				break;
			case DIRECTION_TRANSMIT:
				// Do nothing
				break;
		}

	}

	public void setCompressed(long l, int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				rCompressed=l;
				break;
			case DIRECTION_TRANSMIT:
				tCompressed=l;
				break;
		}

	}
	public void setMulticast(long l, int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				rMulticast=l;
				break;
			case DIRECTION_TRANSMIT:
				// Do nothing
				break;
		}

	}
	public void setColls(long l, int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				// Do nothing
				break;
			case DIRECTION_TRANSMIT:
				tColls = l;
				break;
		}

	}

	public void setCarrier(long l, int direction){
		switch (direction) {
			case DIRECTION_RECEIVE:
				// Do nothing
				break;
			case DIRECTION_TRANSMIT:
				tCarrier = l;
				break;
		}

	}
	public void setName(String s){
		ifName=s;
	}


	public void setStatus(String s){
		ifStatus=s;
	}

	public void dump(){
		System.err.println(ifName);
		System.err.println(ifStatus);
		System.err.println(rBytes);
		System.err.println(rPackets);
		System.err.println(rErrors);
		System.err.println(rDrop);
		System.err.println(rFifo);
		System.err.println(rFrame);
		System.err.println(rCompressed);
		System.err.println(rMulticast);
		System.err.println(tBytes);
		System.err.println(tPackets);
		System.err.println(tErrors);
		System.err.println(tColls);
		System.err.println(tCarrier);
		System.err.println(tDrop);
		System.err.println(tFifo);
		System.err.println(tCompressed);

	}
}

