import java.util.Vector;
import java.awt.event.*;
import java.awt.*;
import java.io.BufferedInputStream;
import java.io.InputStreamReader;
import java.io.BufferedReader;
import java.io.IOException;
import java.net.Socket;


// Lrp Network Monitor: Simple network monitor written in Java
// Copyright (C) 2000 Martin Hejl
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

/**
 * Parent class for all views (numeric, bar, line and histogram)
 * Handles common stuff, but doesn't display any data
 *
 * @author       Martin Hejl
 * @version      20001118 0.2beta
 */
public abstract class LrpStatAbstractGraph extends java.awt.Panel implements LrpStatModelListener, ActionListener {
	protected String deviceName;
	protected InterfaceInfo lastValue;
	protected InterfaceInfo value;
	protected static final int INSETS = 5;
	protected int lineHeight=10;
	protected int statusLineHeight =10;
	protected InterfaceOptions ifOpts;
	protected PopupMenu popup;
	protected Color foregroundColor;
	protected Color backgroundColor;
	protected Font statusFont=null;
	protected int nMaxInSize=0;
	protected int nMaxOutSize=0;
	protected Color screenBackground;

	LrpStatAbstractGraph(InterfaceOptions opts) {

		deviceName = opts.deviceName;
		ifOpts = opts;

		// If there are actions defined, add a menu with these actions
		if (ifOpts.actions.size()>0) {

			popup = new PopupMenu("Actions");
			enableEvents(AWTEvent.MOUSE_EVENT_MASK);

			MenuItem item;
			CommandInfo cmd;
			for (int i=0; i<ifOpts.actions.size(); i++){
				cmd = (CommandInfo)ifOpts.actions.elementAt(i);
				item = new MenuItem(cmd.caption);
				item.setActionCommand(String.valueOf(i));
				item.addActionListener(this);
				popup.add(item);
			}

			add(popup);
		}

		foregroundColor = Color.black;
		backgroundColor = new Color(200,200,200);
		screenBackground = new Color(20,64,20);

	}

	public InterfaceInfo subtract(InterfaceInfo v1, InterfaceInfo v2) {
		return(new InterfaceInfo(
			v1.getName(),
			v1.getStatus(),
			v1.getBytes(InterfaceInfo.DIRECTION_RECEIVE) - v2.getBytes(InterfaceInfo.DIRECTION_RECEIVE),
			v1.getPackets(InterfaceInfo.DIRECTION_RECEIVE) - v2.getPackets(InterfaceInfo.DIRECTION_RECEIVE),
			v1.getErrors(InterfaceInfo.DIRECTION_RECEIVE) - v2.getErrors(InterfaceInfo.DIRECTION_RECEIVE),
			v1.getDrop(InterfaceInfo.DIRECTION_RECEIVE) - v2.getDrop(InterfaceInfo.DIRECTION_RECEIVE),
			v1.getFifo(InterfaceInfo.DIRECTION_RECEIVE) - v2.getFifo(InterfaceInfo.DIRECTION_RECEIVE),
			v1.getFrame(InterfaceInfo.DIRECTION_RECEIVE) - v2.getFrame(InterfaceInfo.DIRECTION_RECEIVE),
			v1.getCompressed(InterfaceInfo.DIRECTION_RECEIVE) - v2.getCompressed(InterfaceInfo.DIRECTION_RECEIVE),
			v1.getMulticast(InterfaceInfo.DIRECTION_RECEIVE) - v2.getMulticast(InterfaceInfo.DIRECTION_RECEIVE),

			v1.getBytes(InterfaceInfo.DIRECTION_TRANSMIT) - v2.getBytes(InterfaceInfo.DIRECTION_TRANSMIT),
			v1.getPackets(InterfaceInfo.DIRECTION_TRANSMIT) - v2.getPackets(InterfaceInfo.DIRECTION_TRANSMIT),
			v1.getErrors(InterfaceInfo.DIRECTION_TRANSMIT) - v2.getErrors(InterfaceInfo.DIRECTION_TRANSMIT),
			v1.getDrop(InterfaceInfo.DIRECTION_TRANSMIT) - v2.getDrop(InterfaceInfo.DIRECTION_TRANSMIT),
			v1.getFifo(InterfaceInfo.DIRECTION_TRANSMIT) - v2.getFifo(InterfaceInfo.DIRECTION_TRANSMIT),
			v1.getCompressed(InterfaceInfo.DIRECTION_TRANSMIT) - v2.getCompressed(InterfaceInfo.DIRECTION_TRANSMIT),
			v1.getColls(InterfaceInfo.DIRECTION_TRANSMIT) - v2.getMulticast(InterfaceInfo.DIRECTION_TRANSMIT),
			v1.getCarrier(InterfaceInfo.DIRECTION_TRANSMIT) - v2.getCarrier(InterfaceInfo.DIRECTION_TRANSMIT)
		));

	}
	public abstract void dataArrived(LrpStatModelEvent e);

	protected Rectangle getClientRect() {
		return (new Rectangle(INSETS, 2*INSETS+lineHeight , getSize().width - 2*INSETS, getSize().height-3*INSETS-lineHeight-statusLineHeight));
	}

	public void drawHeader(Graphics g, String title, Color foreground) {
		// Draw the title
		g.setColor(foreground);
		g.drawString(title, INSETS, INSETS + lineHeight);

	}

	public void drawFooter(Graphics g, long in, long out, Color foreground) {
		Font oldFont=g.getFont();


		g.setFont(statusFont);

		FontMetrics fm;
		fm = g.getFontMetrics();




		if (nMaxInSize==0){
			String s;
			s = "In:" + (new Long(ifOpts.maxThroughput).toString()) + " ";
			nMaxInSize = fm.stringWidth(s);
		}
		if (nMaxOutSize==0){
			String s;
			s = "Out:" + (new Long(ifOpts.maxThroughput).toString());
			nMaxOutSize = fm.stringWidth(s);
		}

		Rectangle clientRect = getClientRect();

		g.setColor(foreground);
		if (nMaxInSize+nMaxOutSize < clientRect.width) {
			int yPos;
			yPos = clientRect.y+clientRect.height+statusLineHeight;
			yPos += ((getSize().height - yPos)/2);

			String s;
			long val;
			val = in ;
			s = "In:" + Long.toString(val) + " ";
			g.drawString(s, clientRect.x, yPos);

			val = out;
			s = "Out:" + Long.toString(val);

			g.drawString(s, clientRect.x + nMaxInSize, yPos);

		}

		g.setFont(oldFont);
	}

	public void paint(Graphics g) {
		FontMetrics fm;
		fm = g.getFontMetrics();



		lineHeight = fm.getLeading() + fm.getMaxAscent() + fm.getMaxDescent();

		Font oldFont=g.getFont();
		if (statusFont==null) {
			statusFont = new Font("Helvetica", 0 , 9);
		}

		g.setFont(statusFont);
		statusLineHeight = fm.getLeading() + fm.getMaxAscent() + fm.getMaxDescent();
		g.setFont(oldFont);

		Rectangle clientRect = getClientRect();

		// Draw the background
		g.setColor(backgroundColor);
		g.fillRect(0,0, getSize().width,getSize().height);
		g.draw3DRect(1,1, getSize().width-2,getSize().height-2, true);


		// Draw the inner border and fill the interior
		// Ok, I finally got why I always seemed to get "empty" areas (areas that would not be filled)

		// From the API-Reference:
		// Coordinates are infinitely thin and lie between the pixels of the output device. Operations which draw the outline of a
		// figure operate by traversing an infinitely thin path between pixels with a pixel-sized pen that hangs down and to the right
		// of the anchor point on the path. Operations which fill a figure operate by filling the interior of that infinitely thin path.

		// So, in short the outer bounds of fillRect(x,y,w,h) and drawRect(x,y,w,h) are different!!!

		g.draw3DRect(clientRect.x-1,
			clientRect.y-1,
			clientRect.width+2,
			clientRect.height+2,
			false);

		g.setColor(screenBackground);
		g.fillRect(clientRect.x , clientRect.y,clientRect.width+1, clientRect.height+1);


		drawHeader(g, deviceName, foregroundColor);


	}

	// Don't clear the background on an uptate - this is done in paint of the implementing classes
	public void update(Graphics g) {
		paint(g);
	}


	public void processMouseEvent(MouseEvent e) {

		if (e.isPopupTrigger()) {
			popup.show(e.getComponent(), e.getX(), e.getY());
		}
		super.processMouseEvent(e);
	}

 	public void	actionPerformed(ActionEvent e) 	{
		int index;
		System.err.println("Executing command " + e.getActionCommand());
		try {
			index = Integer.parseInt(e.getActionCommand());
			System.err.println("Executing command " + index);
			if (index>=0 && index<ifOpts.actions.size()) {
				executeCommand((CommandInfo)ifOpts.actions.elementAt(index));
			}
		} catch (NumberFormatException ex) {return;}


	}

	protected void executeCommand(CommandInfo cmd) {
		switch (cmd.commandType) {
			case CommandInfo.COMMAND_TYPE_GET:
				try {
					cmd.commandURL.openConnection();

					BufferedReader in = new BufferedReader(new InputStreamReader(cmd.commandURL.openStream()));
					String strLine;
					System.err.println("Server responded:");
					while ((strLine = in.readLine()) != null) {
						System.err.println(strLine);
					}
					in.close();
				} catch (IOException e) {}
				break;
			case CommandInfo.COMMAND_TYPE_OPEN:
				try {
					Socket sockServerConnection = new Socket(cmd.commandHost, (int)cmd.commandPort);
					BufferedReader in = new BufferedReader(new InputStreamReader(sockServerConnection.getInputStream()));
					String strLine;
					System.err.println("Server responded:");
					while ((strLine = in.readLine()) != null) {
						System.err.println(strLine);
					}
					in.close();
					sockServerConnection.close();
				} catch (IOException e) {}
				break;
		}
	}
}