import java.util.Vector;
import java.awt.*;
import java.awt.event.*;

// Lrp Network Monitor: Simple network monitor written in Java
// Copyright (C) 2000 Martin Hejl
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

/**
 * Implements a histogram view of the device-data
 *
 * @author       Martin Hejl
 * @version      20001118 0.2beta
 */
public class LrpStatLineGraph extends LrpStatAbstractGraph  {
	Vector hist;


	LrpStatLineGraph(InterfaceOptions opts) {
		super(opts);
	}

	public void paint(Graphics graph) {
		Image offScreenImg = createImage(getSize().width, getSize().height);
		Graphics g = offScreenImg.getGraphics();


		// Draw borders and all the other stuff that's common between all three views
		super.paint(g);

		FontMetrics fm;
		fm = g.getFontMetrics();


		if (lineHeight==0) lineHeight = fm.getLeading() + fm.getMaxAscent() + fm.getMaxDescent();


		if (lastValue == null || value==null) {
			g.setColor(Color.green);
			g.drawString("No data", 2*INSETS, 2*INSETS + 2*lineHeight);
			graph.drawImage(offScreenImg,0,0,this);
			if (hist != null ) {
				hist.removeAllElements();
				hist = null;
			}
			return;
		}



		Rectangle clientRect = getClientRect();

		// if the clientRect.width is 0, we can stop here
		if (clientRect.width == 0) return;

		// get rid of entries that have scrolled out of the window
		while (hist.size() > 2*clientRect.width+2) {
			// Kick the oldest entries
			hist.removeElementAt(0);
			hist.removeElementAt(0);
		}

		drawFooter(g, ((Long)hist.elementAt(hist.size()-2)).longValue(), ((Long)hist.elementAt(hist.size()-1)).longValue(), Color.black);


		g.setColor(Color.green);
		for (int x=0; x<hist.size()-2; x+=2) {
			long throughputIn=((Long)hist.elementAt(x)).longValue();
			long throughputIn2=((Long)hist.elementAt(x+2)).longValue();

			int throughputHeightIn = (int)((throughputIn)*(clientRect.height)/ifOpts.maxThroughput);
			int throughputHeightIn2 = (int)((throughputIn2)*(clientRect.height)/ifOpts.maxThroughput);

			// Do some clipping - just in case the "MaxThroughput" value wasn't realistic
			if (throughputHeightIn>clientRect.height) throughputHeightIn=clientRect.height;
			if (throughputHeightIn2>clientRect.height) throughputHeightIn2=clientRect.height;



			g.drawLine(	clientRect.x+x/2,
						clientRect.y+clientRect.height-throughputHeightIn,
						clientRect.x+x/2+1,
						clientRect.y+clientRect.height-throughputHeightIn2);

		}

		g.setColor(Color.cyan);
		for (int x=0; x<hist.size()-2; x+=2) {
			long throughputOut=((Long)hist.elementAt(x+1)).longValue();
			long throughputOut2=((Long)hist.elementAt(x+3)).longValue();

			int throughputHeightOut = (int)((throughputOut)*(clientRect.height)/ifOpts.maxThroughput);
			int throughputHeightOut2 = (int)((throughputOut2)*(clientRect.height)/ifOpts.maxThroughput);

			// Do some clipping - just in case the "MaxThroughput" value wasn't realistic
			if (throughputHeightOut>clientRect.height) throughputHeightOut=clientRect.height;
			if (throughputHeightOut2>clientRect.height) throughputHeightOut2=clientRect.height;

			g.drawLine(	clientRect.x+x/2,
						clientRect.y+clientRect.height-throughputHeightOut,
						clientRect.x+x/2+1,
						clientRect.y+clientRect.height-throughputHeightOut2);
		}

		graph.drawImage(offScreenImg,0,0,this);
	}

	public void dataArrived(LrpStatModelEvent e) {

		if (lastValue == null ) {
			lastValue=e.getInterfaceInfo();
			hist = new Vector();
		} else {
			lastValue = value;
		}

		value = e.getInterfaceInfo();

		// If reveived a null value, we can stop here
		if (value == null){
			repaint();
			return;
		}

		InterfaceInfo tmpValue = subtract(value, lastValue);
		Long throughputIn=new Long(tmpValue.getBytes(InterfaceInfo.DIRECTION_RECEIVE));
		Long throughputOut=new Long(tmpValue.getBytes(InterfaceInfo.DIRECTION_TRANSMIT));

		hist.addElement((Object)throughputIn);
		hist.addElement((Object)throughputOut);

		repaint();
	}

}