import java.util.Vector;

// Lrp Network Monitor: Simple network monitor written in Java
// Copyright (C) 2000 Martin Hejl
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

/**
 * The class that handles the data (and notifies listeners)
 *
 * @author       Martin Hejl
 * @version      20001105 0.2beta
 */
public class LrpStatModel implements Runnable {
	protected Vector modelListeners;
	protected Vector interfaces;
	protected NetworkConnection con;

	protected boolean stopThread=false;
	protected Vector dataFromNet=null;

	protected int myPort;
	protected String myHost;


	LrpStatModel(String hostname, int port, Vector dev){
		myHost = hostname;
		myPort = port;
	    interfaces = dev;
	    modelListeners = new Vector();

	}


	public void AddModelListener(LrpStatModelListener l, String deviceName) {


		for (int i =0; i<interfaces.size(); i++) {
			if (((InterfaceOptions)(interfaces.elementAt(i))).deviceName.equals(deviceName)) {
				modelListeners.addElement((Object)l);
				modelListeners.addElement((Object)interfaces.elementAt(i));
				break;
			}
		}
	}

	public  void RemoveModelListener(LrpStatModelListener l) {

		for (int i=0; i<modelListeners.size(); i+=2) {
			if ((LrpStatModelListener)modelListeners.elementAt(i) == l) {
				// Remove the InterfaceOptions for this listener
				modelListeners.removeElementAt(i+1);

				// Remove the listener
				modelListeners.removeElementAt(i);

				break;
			}
		}
	}

	public void fireDataChanged() {
		for (int i=0; i<modelListeners.size(); i+=2) {
			String deviceName;
			LrpStatModelListener lst;
			lst = (LrpStatModelListener)modelListeners.elementAt(i);
			deviceName = ((InterfaceOptions)modelListeners.elementAt(i+1)).deviceName;

			lst.dataArrived(new LrpStatModelEvent(this, ((InterfaceOptions)modelListeners.elementAt(i+1)), getDataFor(deviceName)));
		}

	}

	protected InterfaceInfo getDataFor(String deviceName) {
		InterfaceInfo ifInfo;
		if (dataFromNet!=null) {
			for (int i=0; i<dataFromNet.size(); i++) {
				ifInfo = (InterfaceInfo)dataFromNet.elementAt(i);
				if (ifInfo.getName().equals(deviceName)) {
					return(ifInfo);
				}
			}
		}
		return(null);
	}

	public void run() {
		stopThread=false;
		con = new NetworkConnection(myHost, myPort);
		con.open();



		while (!stopThread) {
				dataFromNet = con.fetchResult();
				if (!stopThread) fireDataChanged();

		}
		con.close();
		con = null;
	}

	public void stop() {
		stopThread=true;
	}


}