import java.util.Vector;
import java.awt.*;
import java.awt.event.*;


// Lrp Network Monitor: Simple network monitor written in Java
// Copyright (C) 2000 Martin Hejl
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

/**
 * Implements a text only view of the device-data
 *
 * @author       Martin Hejl
 * @version      20001118 0.2beta
 */
public class LrpStatNumericGraph extends LrpStatAbstractGraph {


	LrpStatNumericGraph(InterfaceOptions opts) {
		super(opts);
	}

	public void paint(Graphics graph) {
		Image offScreenImg = createImage(getSize().width, getSize().height);
		Graphics g = offScreenImg.getGraphics();

		// Draw borders and all the other stuff that's common between all three views
		super.paint(g);

		Rectangle clientRect = getClientRect();

		FontMetrics fm;
		fm = g.getFontMetrics();

		int lineHeight = fm.getLeading() + fm.getMaxAscent() + fm.getMaxDescent();

		if (lastValue == null || value==null) {
			g.setColor(Color.green);
			g.drawString("No data", clientRect.x, clientRect.y + lineHeight);
			graph.drawImage(offScreenImg,0,0,this);
			return;
		}
		int columnWidth = fm.stringWidth("In: ");
		if (fm.stringWidth("Out: ") > columnWidth) columnWidth = fm.stringWidth("Out: ");

		InterfaceInfo paintValue = subtract(value, lastValue);

		drawFooter(g, paintValue.getBytes(InterfaceInfo.DIRECTION_RECEIVE) , paintValue.getBytes(InterfaceInfo.DIRECTION_TRANSMIT), Color.black);

		graph.drawImage(offScreenImg,0,0,this);
	}

	public void dataArrived(LrpStatModelEvent e) {
		if (lastValue == null ) {
			lastValue=e.getInterfaceInfo();
		} else {
			lastValue = value;
		}

		value = e.getInterfaceInfo();

		repaint();
	}


}